@@ -165,7 +165,10 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                                     }
                                 }
                             }
-                            Err(e) => eprintln!("Failed to pull PubSub messages: {}", e),
+                            Err(e) => {
+                                eprintln!("Failed to pull PubSub messages: {}", e);
+                                println!("Failed to pull PubSub messages: {}", e);
+                            },
                         }
                     }
 
